from .xcolor import Color

BLACK = Color("Black")
RED = Color("Red")
GREEN = Color("Green")
YELLOW = Color("Yellow")
BLUE = Color("Blue")
PURPLE = Color("Purple")
CYAN = Color("Cyan")
WHITE = Color("White")

IBLACK = Color("Black", style="Italic")
IRED = Color("Red", style="Italic")
IGREEN = Color("Green", style="Italic")
IYELLOW = Color("Yellow", style="Italic")
IBLUE = Color("Blue", style="Italic")
IPURPLE = Color("Purple", style="Italic")
ICYAN = Color("Cyan", style="Italic")
IWHITE = Color("White", style="Italic")

UBLACK = Color("Black", style="Underline")
URED = Color("Red", style="Underline")
UGREEN = Color("Green", style="Underline")
UYELLOW = Color("Yellow", style="Underline")
UBLUE = Color("Blue", style="Underline")
UPURPLE = Color("Purple", style="Underline")
UCYAN = Color("Cyan", style="Underline")
UWHITE = Color("White", style="Underline")

TBLACK = Color("Black", style="Throughline")
TRED = Color("Red", style="Throughline")
TGREEN = Color("Green", style="Throughline")
TYELLOW = Color("Yellow", style="Throughline")
TBLUE = Color("Blue", style="Throughline")
TPURPLE = Color("Purple", style="Throughline")
TCYAN = Color("Cyan", style="Throughline")
TWHITE = Color("White", style="Throughline")
